@@ -2,11 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import PoolMeta
 
-__all__ = ['FiscalYear']
-__metaclass__ = PoolMeta
 
-
-class FiscalYear:
+class FiscalYear(metaclass=PoolMeta):
     __name__ = 'account.fiscalyear'
 
     @classmethod
