@@ -2,25 +2,17 @@
 # this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 import operator
+
+from trytond.i18n import gettext
 from trytond.pool import Pool, PoolMeta
 from trytond.transaction import Transaction
 
-__all__ = ['InvoiceLine']
+from .exceptions import COGSWarning
 
 
 class InvoiceLine(metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
 
-    @classmethod
-    def __setup__(cls):
-        super(InvoiceLine, cls).__setup__()
-        cls._error_messages.update({
-                'stock_move_different_product': (
-                    "The invoice line '%(line)s' is linked to stock moves "
-                    "for other products than '%(product)s'.\n"
-                    "This may compute a wrong COGS."),
-                })
-
     def _get_anglo_saxon_move_lines(self, amount, type_):
         '''
         Return account move for anglo-saxon stock accounting
@@ -40,13 +32,11 @@ class InvoiceLine(metaclass=PoolMeta):
         if type_.startswith('in_'):
             move_line.debit = amount
             move_line.credit = Decimal('0.0')
-            account_type = type_[3:]
+            move_line.account = self.product.account_stock_in_used
         else:
             move_line.debit = Decimal('0.0')
             move_line.credit = amount
-            account_type = type_[4:]
-        move_line.account = getattr(self.product,
-                'account_stock_%s_used' % account_type)
+            move_line.account = self.product.account_stock_out_used
 
         result.append(move_line)
         debit, credit = move_line.debit, move_line.credit
@@ -67,6 +57,7 @@ class InvoiceLine(metaclass=PoolMeta):
         pool = Pool()
         Move = pool.get('stock.move')
         Period = pool.get('account.period')
+        Warning = pool.get('res.user.warning')
 
         result = super(InvoiceLine, self).get_move_lines()
 
@@ -92,11 +83,12 @@ class InvoiceLine(metaclass=PoolMeta):
             # remove move for different product
             if move.product != self.product:
                 warning_name = '%s.stock.different_product' % self
-                self.raise_user_warning(
-                    warning_name, 'stock_move_different_product', {
-                        'line': self.rec_name,
-                        'product': self.product.rec_name,
-                        })
+                if Warning.check(warning_name):
+                    raise COGSWarning(warning_name,
+                        gettext('account_stock_anglo_saxon'
+                            '.msg_invoice_line_stock_move_different_product',
+                            line=self.rec_name,
+                            product=self.product.rec_name))
             else:
                 moves.append(move)
 
@@ -117,7 +109,8 @@ class InvoiceLine(metaclass=PoolMeta):
             self.product, moves, abs(self.quantity), self.unit, type_)
         cost = self.invoice.company.currency.round(cost)
 
-        with Transaction().set_context(date=accounting_date):
+        with Transaction().set_context(
+                company=self.invoice.company.id, date=accounting_date):
             anglo_saxon_move_lines = self._get_anglo_saxon_move_lines(
                 cost, type_)
         result.extend(anglo_saxon_move_lines)
